<?php 
/*
Plugin Name: Internal link
Plugin URI: http://www.johanronstrom.se/
Description: Allows you to select a page and creates a link to it.
Version: 0.1
Author: Johan Ronstrm
Author URI: http://www.johanronstrom.se/
*/ 

/*  Copyright 2007-2008  Johan Ronstrm

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

// Find the full URL to the plugin directory and store it
global $internallink_plugin_url;
$internallink_plugin_url = dirname(get_settings('siteurl') . '/wp-content/plugins/' . preg_replace('/^.*wp-content\/plugins\//', '', str_replace('\\', '/', __FILE__)));

// Set up hooks for the plugin
add_action('admin_footer', 'internallink_plugin_footer');
add_action('wp_head', 'internallink_plugin_head');
add_action('marker_css', 'internallink_plugin_css');
add_action('init', 'internallink_plugin_init');
add_action('admin_menu', 'internallink_plugin_menu');

function internallink_plugin_init() {
  if (get_user_option('rich_editing') == 'true') {
    // Include hooks for TinyMCE plugin
    add_filter('mce_external_plugins', 'internallink_plugin_mce_external_plugins');
    add_filter('mce_buttons_3', 'internallink_plugin_mce_buttons');
  }
} // End internallink_plugin_init()

function internallink_plugin_menu() {
  if (function_exists('add_options_page')) {
    add_options_page('Internal link Options', 'Internal link', 8, __FILE__,
      'internallink_plugin_options_page');
  }
} // End internallink_plugin_menu()

function internallink_plugin_options_page() {
?><div class="wrap">
<h2>Internal link Support for Editor</h2>
<form method="post" action="options.php">
<?php wp_nonce_field('update-options'); ?>
<table class="form-table">
<tr valign="top">
<th scope="row">Rating text</th>
<td><input type="text" name="internallink_rating_text" value="<?php echo get_option('internallink_rating_text'); ?>" /></td>
</tr>
<tr valign="top">
<th scope="row">Stars text</th>
<td><input type="text" name="internallink_stars_text" value="<?php echo get_option('internallink_stars_text'); ?>" /></td>
</tr>
</table>
<input type="hidden" name="action" value="update" />
<input type="hidden" name="page_options" value="internallink_rating_text,internallink_stars_text" />
<p class="submit">
<input type="submit" name="Submit" value="<?php _e('Save Changes') ?>" />
</p></form></div>
<?php
} // End internallink_plugin_options_page()

function internallink_plugin_mce_external_plugins($plugins) {
  global $internallink_plugin_url;
  $plugins['internallink_plugin'] = $internallink_plugin_url . '/tinymceplugin/editor_plugin.js';
  return $plugins;
} // End internallink_plugin_mce_external_plugins()

function internallink_plugin_mce_buttons($buttons) {
  array_push($buttons, 'internallink_button');
  return $buttons;
} // End internallink_plugin_mce_buttons()

function internallink_plugin_footer() {
  global $internallink_plugin_url;
?>
<script type="text/javascript">//<![CDATA[
  var internallink_from_gui;

  function edInsertInternalLink() {
    tb_show("Add an Internal link", "<?php echo $internallink_plugin_url; ?>/internallink-input.php?TB_iframe=true");
    internallink_from_gui = true; /** Called from TinyMCE **/
  } // End edInsertInternalLink()

  function edInsertInternalLinkCode() {
    tb_show("Add an Internal link", "<?php echo $internallink_plugin_url; ?>/internallink-input.php?TB_iframe=true");
    internallink_from_gui = false; /** Called from Quicktags **/
  } // End edInsertInternalLink()

  if (internallink_qttoolbar = document.getElementById("ed_toolbar")){
    newbutton = document.createElement("input");
    newbutton.type = "button";
    newbutton.id = "ed_internallink";
    newbutton.className = "ed_button";
    newbutton.value = "Internal link";
    newbutton.onclick = edInsertInternalLinkCode;
    internallink_qttoolbar.appendChild(newbutton);
  }

  function edInsertInternalLinkAbort() {
    tb_remove();
  } // End edInsertInternalLinkAbort()

  function edInsertInternalLinkDone(itemPageId) {
    tb_remove();

	// find selection
	if (document.selection)
	{
		var il_selectedText = document.selection.createRange().text;
	}
	else
	{
		var il_txtArea = document.getElementById("content");
		var il_text = il_txtArea.value;
		var il_selectedText = il_text.substring(il_txtArea.selectionStart,il_txtArea.selectionEnd);
	}

	if (il_selectedText == 0)
	{
		il_selectedText = itemPageId;
	}

    var InternalLinkOutput = '<a href="' + itemPageId + '">' + il_selectedText + '</a>';

    if (internallink_from_gui)
    {
      tinyMCE.execInstanceCommand('content', 'mceInsertContent', false, InternalLinkOutput);
      tinyMCE.execCommand('mceCleanup');
    } else
    {
      edInsertContent(edCanvas, InternalLinkOutput);
    }
  } // End edInsertInternalLinkDone()
//]]></script>
<?php
} // End internallink_plugin_footer()

function internallink_plugin_head() {
  global $internallink_plugin_url;
  echo '<link rel="stylesheet" type="text/css" media="screen" href="' .
    $internallink_plugin_url . '/internallink.css" />';
} // End internallink_plugin_head()

function internallink_plugin_css() {
  global $internallink_plugin_url;
  echo '@import url( ' . $internallink_plugin_url . '/internallink-editor.css );';
} // End internallink_plugin_css()

?>
